==> aria2_0.9.0.orig.tar.gz: aria2-0.9.0/src/Directory.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "Directory.h"
#include "File.h"
#include "DlAbortEx.h"
#include "message.h"
#include <errno.h>
#include <sys/stat.h>
#include <sys/types.h>

Directory::Directory(const string& name):name(name) {}

Directory::Directory() {}

Directory::~Directory() {
  for(Files::iterator itr = files.begin(); itr != files.end(); itr++) {
    delete *itr;
  }
}

void Directory::createDir(const string& parentDir, bool recursive) const {
  if(name.size() == 0) {
    return;
  }
  string path = parentDir+"/"+name;
  File f(path);
  if(f.exists()) {
    if(!f.isDir()) {
      throw new DlAbortEx(EX_NOT_DIRECTORY, path.c_str());
    }
  } else {
    if(mkdir(path.c_str(), S_IRUSR|S_IWUSR|S_IXUSR) == -1) {
      throw new DlAbortEx(EX_MAKE_DIR, path.c_str(), strerror(errno));
    }
  }
  if(recursive) {
    for(Files::const_iterator itr = files.begin(); itr != files.end(); itr++) {
      (*itr)->createDir(path, true);
    }
  }
}

void Directory::addFile(Directory* directory) {
  files.push_back(directory);
}

==> aria2_0.11.0.orig.tar.gz: aria2-0.11.0/src/Directory.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "Directory.h"
#include "File.h"
#include "DlAbortEx.h"
#include "message.h"
#include <errno.h>
#include <sys/stat.h>
#include <sys/types.h>

Directory::Directory(const string& name):name(name) {}

Directory::Directory() {}

Directory::~Directory() {
  for(Files::iterator itr = files.begin(); itr != files.end(); itr++) {
    delete *itr;
  }
}

void Directory::createDir(const string& parentDir, bool recursive) const {
  if(name.size() == 0) {
    return;
  }
  string path = parentDir+"/"+name;
  File f(path);
  if(f.exists()) {
    if(!f.isDir()) {
      throw new DlAbortEx(EX_NOT_DIRECTORY, path.c_str());
    }
  } else {
    if(mkdir(path.c_str(), OPEN_MODE) == -1) {
      throw new DlAbortEx(EX_MAKE_DIR, path.c_str(), strerror(errno));
    }
  }
  if(recursive) {
    for(Files::const_iterator itr = files.begin(); itr != files.end(); itr++) {
      (*itr)->createDir(path, true);
    }
  }
}

void Directory::addFile(Directory* directory) {
  files.push_back(directory);
}
